@@ -38,4 +38,7 @@ default_config = {
     "gradient_smoothing_coeff": None,
     "gradient_smoothing_kernel_size": None,
     "grad_mask": None,
+    "max_roll_x": None,
+    "max_roll_y": None,
+    "add_laplacian": False  ## True: preserve high frequency components 
 }
\ No newline at end of file
